@@ -292,6 +292,7 @@ eog_image_init (EogImage *img)
 	img->priv->width = -1;
 	img->priv->height = -1;
 	img->priv->modified = FALSE;
+	img->priv->file_is_changed = FALSE;
 	img->priv->status_mutex = g_mutex_new ();
 	img->priv->status = EOG_IMAGE_STATUS_UNKNOWN;
         img->priv->metadata_status = EOG_IMAGE_METADATA_NOT_READ;
@@ -1151,6 +1152,8 @@ eog_image_real_load (EogImage *img,
 				priv->file_type = gdk_pixbuf_format_get_name (format);
 			}
 
+			priv->file_is_changed = FALSE;
+
 			/* If it's non-threadsafe loader, then trigger window
  			 * showing in the end of the process. */
 			if (!priv->threadsafe_format)
@@ -2226,12 +2229,22 @@ eog_image_get_transform (EogImage *img)
  * eog_image_file_changed:
  * @img: a #EogImage
  *
- * Emits EogImage::file-changed signal
+ * Marks the image file contents as changed. Also, emits
+ * EogImage::file-changed signal.
  **/
 void
 eog_image_file_changed (EogImage *img)
 {
 	g_return_if_fail (EOG_IS_IMAGE (img));
 
+	img->priv->file_is_changed = TRUE;
 	g_signal_emit (img, signals[SIGNAL_FILE_CHANGED], 0);
 }
+
+gboolean
+eog_image_is_file_changed (EogImage *img)
+{
+	g_return_val_if_fail (EOG_IS_IMAGE (img), TRUE);
+
+	return img->priv->file_is_changed;
+}
